@@ -48,7 +48,7 @@
 #define WINDOW_FAX_PROJECT				_("fax project")
 #define WINDOW_FAX_PROJECT_BROWSE			_("browse for fax project")
 #define WINDOW_FAX_RENAME				_("rename fax page")
-#define WINDOW_FAX_INSERT				_("insert ps-file into fax")
+#define WINDOW_FAX_INSERT				_("insert PS-file into fax")
 #define WINDOW_EMAIL_PROJECT				_("E-mail project")
 #define WINDOW_EMAIL_PROJECT_BROWSE			_("browse for email project")
 #define WINDOW_EMAIL_RENAME				_("rename e-mail image")
@@ -161,22 +161,21 @@
 #define RADIO_BUTTON_SAVE_DEVPREFS_AT_EXIT		_("Save device preferences at exit")
 #define RADIO_BUTTON_OVERWRITE_WARNING			_("Overwrite warning")
 #define RADIO_BUTTON_SKIP_EXISTING_NRS			_("Skip existing filenames")
-#define RADIO_BUTTON_SAVE_PS_FLATEDECODED		_("Save postscript zlib compressed (ps level 3)")
+#define RADIO_BUTTON_SAVE_PS_FLATEDECODED		_("Save postscript zlib compressed (PS level 3)")
 #define RADIO_BUTTON_SAVE_PDF_FLATEDECODED		_("Save PDF zlib compressed")
-#define RADIO_BUTTON_SAVE_PNM16_AS_ASCII		_("Save 16bit pnm in ascii format")
+#define RADIO_BUTTON_SAVE_PNM16_AS_ASCII		_("Save 16bit PNM in ASCII format")
 #define RADIO_BUTTON_REDUCE_16BIT_TO_8BIT		_("Reduce 16 bit image to 8 bit")
 #define RADIO_BUTTON_WINDOW_FIXED			_("Main window size fixed")
 #define RADIO_BUTTON_DISABLE_GIMP_PREVIEW_GAMMA		_("Disable GIMP preview gamma")
 #define RADIO_BUTTON_PRIVATE_COLORMAP			_("Use private colormap")
 #define RADIO_BUTTON_AUTOENHANCE_GAMMA  		_("Autoenhance gamma")
-#define RADIO_BUTTON_PRESELECT_SCANAREA 		_("Preselect scanarea")
+#define RADIO_BUTTON_PRESELECT_SCAN_AREA 		_("Preselect scan area")
 #define RADIO_BUTTON_AUTOCORRECT_COLORS 		_("Autocorrect colors")
 #define RADIO_BUTTON_OCR_USE_GUI_PIPE			_("Use GUI progress pipe")
 #define RADIO_BUTTON_CMS_BPC				_("Black point compensation")
 
 #define TEXT_SCANNING_DEVICES				_("scanning for devices")
 #define TEXT_AVAILABLE_DEVICES				_("Available devices:")
-#define TEXT_XSANE_OPTIONS				_("XSane options")
 #define TEXT_FILETYPE					_("Type")
 #define TEXT_CMS_FUNCTION				_("Color management function")
 #define TEXT_SCANNER_BACKEND				_("Scanner and backend:")
@@ -274,21 +273,24 @@
 #define TEXT_SETUP_PRINTER_NAME				_("Name:")
 #define TEXT_SETUP_PRINTER_CMD				_("Command:")
 #define TEXT_SETUP_COPY_NR_OPT				_("Copy number option:")
-#define TEXT_SETUP_PRINTER_LINEART_RES			_("Lineart resolution (dpi):")
-#define TEXT_SETUP_PRINTER_GRAYSCALE_RES		_("Grayscale resolution (dpi):")
-#define TEXT_SETUP_PRINTER_COLOR_RES			_("Color resolution (dpi):")
-#define TEXT_SETUP_PRINTER_WIDTH			_("Width")
-#define TEXT_SETUP_PRINTER_HEIGHT			_("Height")
-#define TEXT_SETUP_PRINTER_LEFT				_("Left offset")
-#define TEXT_SETUP_PRINTER_BOTTOM			_("Bottom offset")
-#define TEXT_SETUP_PRINTER_GAMMA			_("Printer gamma value:")
-#define TEXT_SETUP_PRINTER_GAMMA_RED			_("Printer gamma red:")
-#define TEXT_SETUP_PRINTER_GAMMA_GREEN			_("Printer gamma green:")
-#define TEXT_SETUP_PRINTER_GAMMA_BLUE			_("Printer gamma blue:")
+#define TEXT_SETUP_SCAN_RESOLUTION_PRINTER		_("Scan resolution:")
+#define TEXT_SETUP_PRINTER_LINEART_RES			_("lineart [dpi]")
+#define TEXT_SETUP_PRINTER_GRAYSCALE_RES		_("grayscale [dpi]")
+#define TEXT_SETUP_PRINTER_COLOR_RES			_("color [dpi]")
+#define TEXT_SETUP_PRINTER_PAPER_GEOMETRIE		_("Paper geometrie:")
+#define TEXT_SETUP_PRINTER_WIDTH			_("width")
+#define TEXT_SETUP_PRINTER_HEIGHT			_("height")
+#define TEXT_SETUP_PRINTER_LEFT				_("left offset")
+#define TEXT_SETUP_PRINTER_BOTTOM			_("bottom offset")
+#define TEXT_SETUP_PRINTER_GAMMA_CORRECTION		_("Printer gamma:")
+#define TEXT_SETUP_PRINTER_GAMMA			_("common value")
+#define TEXT_SETUP_PRINTER_GAMMA_RED			_("red")
+#define TEXT_SETUP_PRINTER_GAMMA_GREEN			_("green")
+#define TEXT_SETUP_PRINTER_GAMMA_BLUE			_("blue")
 #define TEXT_SETUP_PRINTER_EMBED_CSA			_("Embed scanner ICM profile as CSA")
 #define TEXT_SETUP_PRINTER_EMBED_CRD			_("Embed printer ICM profile as CRD")
 #define TEXT_SETUP_PRINTER_CMS_BPC			_("Apply black point compensation")
-#define TEXT_SETUP_PRINTER_PS_FLATEDECODED		_("Create zlib compressed postscript image (ps level 3) for printing")
+#define TEXT_SETUP_PRINTER_PS_FLATEDECODED		_("Create zlib compressed postscript image (PS level 3) for printing")
 #define TEXT_SETUP_TMP_PATH				_("Temporary directory")
 #define TEXT_SETUP_IMAGE_PERMISSION			_("Image-file permissions")
 #define TEXT_SETUP_DIR_PERMISSION			_("Directory permissions")
@@ -324,7 +326,7 @@
 #define TEXT_SETUP_FAX_HEIGHT				_("Height")
 #define TEXT_SETUP_FAX_LEFT				_("Left offset")
 #define TEXT_SETUP_FAX_BOTTOM				_("Bottom offset")
-#define TEXT_SETUP_FAX_PS_FLATEDECODED			_("Create zlib compressed postscript image (ps level 3) for fax")
+#define TEXT_SETUP_FAX_PS_FLATEDECODED			_("Create zlib compressed postscript image (PS level 3) for fax")
 #define TEXT_SETUP_SMTP_SERVER				_("SMTP server:")
 #define TEXT_SETUP_SMTP_PORT				_("SMTP port:")
 #define TEXT_SETUP_EMAIL_FROM				_("From:")
@@ -426,8 +428,8 @@
 #define MENU_ITEM_COUNTER_LEN_INACTIVE	_("inactive")
 #define MENU_ITEM_TIFF_COMP_NONE	_("no compression")
 #define MENU_ITEM_TIFF_COMP_CCITTRLE	_("CCITT 1D Huffman compression")
-#define MENU_ITEM_TIFF_COMP_CCITFAX3	_("CCITT Group 3 Fax compression")
-#define MENU_ITEM_TIFF_COMP_CCITFAX4	_("CCITT Group 4 Fax compression")
+#define MENU_ITEM_TIFF_COMP_CCITFAX3	_("CCITT Group 3 fax compression")
+#define MENU_ITEM_TIFF_COMP_CCITFAX4	_("CCITT Group 4 fax compression")
 #define MENU_ITEM_TIFF_COMP_JPEG	_("JPEG DCT compression")
 #define MENU_ITEM_TIFF_COMP_PACKBITS	_("pack bits")
 #define MENU_ITEM_TIFF_COMP_DEFLATE	_("deflate")
@@ -467,7 +469,7 @@
 #define PROGRESS_RECEIVING_FRAME_DATA	_("Receiving %s data")
 #define PROGRESS_PAGE			_("page")
 
-#define PROGRESS_TRANSFERING_DATA	_("Transfering image")
+#define PROGRESS_TRANSFERRING_DATA	_("Transferring image")
 #define PROGRESS_ROTATING_DATA		_("Rotating image")
 #define PROGRESS_MIRRORING_DATA		_("Mirroring image")
 #define PROGRESS_PACKING_DATA		_("Packing image")
@@ -487,7 +489,7 @@
 #define DESC_XSANE_MODE			_("viewer-<Ctrl-v>, save-<Ctrl-s>, photocopy-<Ctrl-c>, " \
 					  "multipage-<Ctrl-m>, fax-<Ctrl-f> or e-mail-<Ctrl-e>")
 #define DESC_XSANE_MEDIUM		_("Select source medium type.\n" \
-					  "To rename, reorder or delete an entry use context menu (right mouse button).\n"\
+					  "To rename, reorder or delete an entry use context menu (alternate mouse button).\n"\
 					  "To create a medium enable the option edit medium definition in preferences menu.")
 
 #define DESC_FILENAME_COUNTER_STEP	_("Value that is added to filenamecounter after scan")
@@ -584,22 +586,22 @@
                                           "The printer has to understand postscript level 3!")
 #define DESC_TMP_PATH			_("Path to temp directory")
 #define DESC_BUTTON_TMP_PATH_BROWSE	_("Browse for temporary directory")
-#define DESC_JPEG_QUALITY		_("Quality in percent if image is saved as jpeg or tiff with jpeg compression")
-#define DESC_PNG_COMPRESSION		_("Compression if image is saved as png")
+#define DESC_JPEG_QUALITY		_("Quality in percent if image is saved as JPEG or TIFF with JPEG compression")
+#define DESC_PNG_COMPRESSION		_("Compression if image is saved as PNG")
 #define DESC_FILENAME_COUNTER_LEN	_("Minimum length of counter in filename")
-#define DESC_TIFF_ZIP_COMPRESSION	_("Compression rate for zip compressed tiff (deflate)")
-#define DESC_TIFF_COMPRESSION_16	_("Compression type if 16 bit image is saved as tiff")
-#define DESC_TIFF_COMPRESSION_8		_("Compression type if 8 bit image is saved as tiff")
-#define DESC_TIFF_COMPRESSION_1		_("Compression type if lineart image is saved as tiff")
+#define DESC_TIFF_ZIP_COMPRESSION	_("Compression rate for zip compressed TIFF (deflate)")
+#define DESC_TIFF_COMPRESSION_16	_("Compression type if 16 bit image is saved as TIFF")
+#define DESC_TIFF_COMPRESSION_8		_("Compression type if 8 bit image is saved as TIFF")
+#define DESC_TIFF_COMPRESSION_1		_("Compression type if lineart image is saved as TIFF")
 #define DESC_SAVE_DEVPREFS_AT_EXIT	_("Save device dependant preferences in default file at exit of xsane")
 #define DESC_OVERWRITE_WARNING		_("Warn before overwriting an existing file")
 #define DESC_SKIP_EXISTING		_("If filename counter is automatically increased, used numbers are skipped")
 #define DESC_SAVE_PS_FLATEDECODED	_("compress postscript image with zlib algorithm (flatedecode). " \
                                           "When you want to print such a file your printer has to understand postscript level 3")
 #define DESC_SAVE_PDF_FLATEDECODED	_("compress PDF image with zlib algorithm (flatedecode).")
-#define DESC_SAVE_PNM16_AS_ASCII	_("When a 16 bit image shall be saved in pnm format then use ascii format " \
+#define DESC_SAVE_PNM16_AS_ASCII	_("When a 16 bit image shall be saved in PNM format then use ASCII format " \
                                           "instead of binary format. The binary format is a new format that is not " \
-                                          "supported by all programs. The ascii format is supported by more programs " \
+                                          "supported by all programs. The ASCII format is supported by more programs " \
                                           "but it produces really huge files!!!")
 #define DESC_REDUCE_16BIT_TO_8BIT	_("If scanner sends image with 16 bits/channel save image with 8 bits/channel")
 #define DESC_PSFILE_WIDTH		_("Width of paper for postscript files")
@@ -610,7 +612,7 @@
 #define DESC_DISABLE_GIMP_PREVIEW_GAMMA	_("Disable preview gamma when XSane runs as GIMP plugin")
 #define DESC_PREVIEW_COLORMAP		_("Use an own colormap for preview if display depth is 8 bpp")
 #define DESC_SHOW_RANGE_MODE		_("Select how a range is displayed")
-#define DESC_PREVIEW_OVERSAMPLING	_("Value with that the calculated preview resolution is multiplied")
+#define DESC_PREVIEW_OVERSAMPLING	_("Value with which the calculated preview resolution is multiplied")
 #define DESC_PREVIEW_GAMMA		_("Set gamma correction value for preview image")
 #define DESC_PREVIEW_GAMMA_RED		_("Set gamma correction value for red component of preview image")
 #define DESC_PREVIEW_GAMMA_GREEN	_("Set gamma correction value for green component of preview image")
@@ -625,9 +627,9 @@
 #define DESC_PREVIEW_THRESHOLD_OFF      _("Offset to make XSane threshold range and scanner threshold range the same")
 #define DESC_ADF_PAGES_MAX		_("Number of pages to scan")
 #define DESC_PREVIEW_PIPETTE_RANGE	_("dimension of square that is used to average color for pipette function")
-#define DESC_DOC_VIEWER			_("Enter command to be executed to display helpfiles, must be a html-viewer!")
+#define DESC_DOC_VIEWER			_("Enter command to be executed to display helpfiles, must be a HTML-viewer!")
 #define DESC_AUTOENHANCE_GAMMA		_("Change gamma value when autoenhancement button is pressed")
-#define DESC_PRESELECT_SCANAREA		_("Select scanarea after preview scan has finished")
+#define DESC_PRESELECT_SCAN_AREA	_("Select scan area after preview scan has finished")
 #define DESC_AUTOCORRECT_COLORS		_("Do color correction after preview scan has finished")
 
 #define DESC_RENDERING_INTENT		_("Select rendering intent for preview and saving")
@@ -654,12 +656,12 @@
 #define DESC_EMAIL_AUTH_PASS		_("password for e-mail server")
 #define DESC_POP3_SERVER		_("IP Address or Domain name of POP3 server")
 #define DESC_POP3_PORT			_("port to connect to POP3 server")
-#define DESC_HTML_EMAIL			_("E-mail is sent in html mode, place image with: <IMAGE>")
-#define DESC_OCR_COMMAND		_("Enter command to start ocr program")
-#define DESC_OCR_INPUTFILE_OPT		_("Enter option of the ocr program to define input file")
-#define DESC_OCR_OUTPUTFILE_OPT		_("Enter option of the ocr program to define output file")
-#define DESC_OCR_USE_GUI_PIPE_OPT	_("Define if the ocr program supports gui progress pipe")
-#define DESC_OCR_OUTFD_OPT		_("Enter option of the ocr program to define output filedescripor in GUI mode")
+#define DESC_HTML_EMAIL			_("E-mail is sent in HTML mode, place image with: <IMAGE>")
+#define DESC_OCR_COMMAND		_("Enter command to start OCR program")
+#define DESC_OCR_INPUTFILE_OPT		_("Enter option of the OCR program to define input file")
+#define DESC_OCR_OUTPUTFILE_OPT		_("Enter option of the OCR program to define output file")
+#define DESC_OCR_USE_GUI_PIPE_OPT	_("Define if the OCR program supports gui progress pipe")
+#define DESC_OCR_OUTFD_OPT		_("Enter option of the OCR program to define output filedescripor in GUI mode")
 #define DESC_OCR_PROGRESS_KEYWORD	_("Define Keyword that is used to mark progress information")
 
 #define DESC_PERMISSION_READ		_("read")
@@ -671,19 +673,19 @@
 #define DESC_PIPETTE_GRAY		_("Pick gray point")
 #define DESC_PIPETTE_BLACK		_("Pick black point")
 
-#define DESC_ZOOM_FULL			_("Use full scanarea")
+#define DESC_ZOOM_FULL			_("Use full scan area")
 #define DESC_ZOOM_OUT			_("Zoom 20% out")
 #define DESC_ZOOM_IN			_("Click at position to zoom to")
 #define DESC_ZOOM_AREA			_("Zoom into selected area")
 #define DESC_ZOOM_UNDO			_("Undo last zoom")
 
 #define DESC_FULL_PREVIEW_AREA		_("Select visible area")
-#define DESC_AUTOSELECT_SCANAREA	_("Autoselect scanarea")
-#define DESC_AUTORAISE_SCANAREA		_("Autoraise scanarea")
+#define DESC_AUTOSELECT_SCAN_AREA	_("Autoselect scan area")
+#define DESC_AUTORAISE_SCAN_AREA	_("Autoraise scan area")
 #define DESC_DELETE_IMAGES		_("Delete preview image cache")
 
 #define DESC_PRESET_AREA		_("Preset area:\n" \
-					  "To add new area or edit an existing area use contect menu (right mouse button).")
+					  "To add new area or edit an existing area use context menu (alternate mouse button).")
 #define DESC_ROTATION			_("Rotate preview and scan")
 #define DESC_RATIO			_("Aspect ratio of selection")
 #define DESC_PAPER_ORIENTATION		_("Define image position for printing")
@@ -695,9 +697,9 @@
 #define DESC_VIEWER_SCALE		_("Scale image")
 #define DESC_VIEWER_DESPECKLE		_("Despeckle image")
 #define DESC_VIEWER_BLUR		_("Blur image")
-#define DESC_ROTATE90			_("Rotate image 90 degree")
-#define DESC_ROTATE180			_("Rotate image 180 degree")
-#define DESC_ROTATE270			_("Rotate image 270 degree")
+#define DESC_ROTATE90			_("Rotate image 90 degrees")
+#define DESC_ROTATE180			_("Rotate image 180 degrees")
+#define DESC_ROTATE270			_("Rotate image 270 degrees")
 #define DESC_MIRROR_X			_("Mirror image at vertical axis")
 #define DESC_MIRROR_Y			_("Mirror image at horizontal axis")
 #define DESC_VIEWER_ZOOM		_("Zoom image")
@@ -706,8 +708,8 @@
 #define DESC_SCALE_FACTOR		_("Scale factor")
 #define DESC_X_SCALE_FACTOR		_("X-Scale factor")
 #define DESC_Y_SCALE_FACTOR		_("Y-Scale factor")
-#define DESC_SCALE_WIDTH		_("Scale image to width [in pixel]")
-#define DESC_SCALE_HEIGHT		_("Scale image to height [in pixel]")
+#define DESC_SCALE_WIDTH		_("Scale image to width [pixels]")
+#define DESC_SCALE_HEIGHT		_("Scale image to height [pixels]")
 #define DESC_BATCH_LIST_EMPTY		_("Empty batch list")
 #define DESC_BATCH_LIST_SAVE		_("Save batch list")
 #define DESC_BATCH_LIST_LOAD		_("Load batch list")
@@ -748,7 +750,7 @@ write permissions." )
 #define ERR_BAD_DEPTH			_("Can't handle depth")
 #define ERR_UNKNOWN_SAVING_FORMAT	_("Unknown file format for saving")
 #define ERR_OPEN_FAILED			_("Failed to open")
-#define ERR_CREATE_SECURE_FILE		_("Could not create secure file (may be a link does exist):")
+#define ERR_CREATE_SECURE_FILE		_("Could not create secure file (maybe a link does exist):")
 #define ERR_FAILED_PRINTER_PIPE		_("Failed to open pipe for executing printercommand")
 #define ERR_FAILED_EXEC_PRINTER_CMD	_("Failed to execute printercommand:")
 #define ERR_FAILED_START_SCANNER	_("Failed to start scanner:")
@@ -767,7 +769,7 @@ write permissions." )
 #define ERR_FAILED_EXEC_DOC_VIEWER	_("Failed to execute documentation viewer:")
 #define ERR_FAILED_EXEC_FAX_VIEWER	_("Failed to execute fax viewer:")
 #define ERR_FAILED_EXEC_FAX_CMD		_("Failed to execute fax command:")
-#define ERR_FAILED_EXEC_OCR_CMD		_("Failed to execute ocr command:")
+#define ERR_FAILED_EXEC_OCR_CMD		_("Failed to execute OCR command:")
 #define ERR_BAD_FRAME_FORMAT		_("bad frame format")
 #define ERR_FAILED_SET_RESOLUTION	_("unable to set resolution")
 #define ERR_PASSWORD_FILE_INSECURE	_("Password file (%s) is insecure, use permission x00\n")
@@ -788,7 +790,7 @@ write permissions." )
 #define WARN_NO_VALUE_CONSTRAINT	_("warning: option has no value constraint")
 #define WARN_XSANE_AS_ROOT		_("You try to run XSane as ROOT, that really is DANGEROUS!\n\n\
 Do not send any bug reports when you\n\
-have any problem while running XSane as root:\n\
+have any problems while running XSane as root:\n\
 YOU ARE ALONE!\
 ")
 
@@ -877,7 +879,7 @@ The format of [DEVICE] is backendname:devicefile (e.g. umax:/dev/scanner).\n\
 				"2) Supported devices are busy\n" \
 				"3) The permissions for the device file do not allow you to use it - try as root\n" \
 				"4) The backend is not loaded by SANE (man sane-dll)\n" \
-				"5) The backend is not configured correct (man sane-\"backendname\")\n" \
+				"5) The backend is not configured correctly (man sane-\"backendname\")\n" \
 				"6) Possibly there is more than one SANE version installed" )
 
 /* strings that are used in structures, so it is not allowed to use _()/gettext() here */
@@ -933,7 +935,7 @@ The format of [DEVICE] is backendname:devicefile (e.g. umax:/dev/scanner).\n\
 #define TEXT_EMAIL_STATUS_SENDING		N_("Sending e-mail")
 #define TEXT_EMAIL_STATUS_SENT			N_("E-mail has been sent")
 
-#define TEXT_FAX_STATUS_QUEUEING_FAX		N_("Queueing Fax")
+#define TEXT_FAX_STATUS_QUEUEING_FAX		N_("Queueing fax")
 #define TEXT_FAX_STATUS_FAX_QUEUED		N_("Fax is queued")
 
 #endif
